=encoding utf8

=head1 NAME

Ann::Latn - Package for language Ann

=cut

package Locale::CLDR::Locales::Ann::Latn;

# This file auto generated
#	on Fri 19 Jan  8:02:59 am GMT

use version;

our $VERSION = version->declare('v0.44.0');

use v5.10.1;
use mro 'c3';
use if $^V ge v5.12.0, feature => 'unicode_strings';

use Moo;

extends('Locale::CLDR::Locales::Ann');

no Moo;

1;
